@@ -3,8 +3,11 @@ from .layouts import (
     CVBoxLayout,
     CHBoxLayout,
     CGridLayout,
+    CSplitter, 
+    PersistentCSplitter,
+    CScrollArea, 
+    PersistentCScrollArea,
 )
-from .splitter import CSplitter, PersistentCSplitter
 from .buttons import StateButton, IconToggleButton, ConfirmToggleButton
 from .labeledit import LabelEdit
 from .link_label import LinkLabel
